var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import ServiceBase from '../base';
import AccountModelProxy from '../proxies/account-model-proxy';
import { AccountPageProxy, PublicAccountInfoProxy } from '../proxies/account-page-proxy';
import { AccountEmailInscribeProxy, AccountProfileProxy } from '../proxies/account-profile-proxy';
import * as proxy from '../proxy';
var GET_ACCOUNT = '/accounts';
var AccountService = /** @class */ (function (_super) {
    __extends(AccountService, _super);
    function AccountService() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.getAllAccounts = function (data) {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT,
                params: data,
            });
            return proxy.httpResultProxy(promise, AccountPageProxy);
        };
        _this.getAccountByAccountId = function (data) {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId,
            });
            return proxy.httpResultProxy(promise, AccountModelProxy);
        };
        _this.getAccountPublicInfo = function (data) {
            var promise = _super.prototype.getWithoutToken.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/publicInfo",
            });
            return proxy.httpResultProxy(promise, PublicAccountInfoProxy);
        };
        _this.addAccount = function (data) {
            var promise = _super.prototype.post.call(_this, {
                url: GET_ACCOUNT,
                data: data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.shiftAccountActive = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/state",
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.updateAccount = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + ("/" + data.accountId),
                data: data.data,
            });
            return proxy.httpResultProxy(promise, AccountModelProxy);
        };
        _this.createPersonalAccount = function () {
            var promise = _super.prototype.post.call(_this, {
                url: GET_ACCOUNT + "/personal",
            });
            return proxy.httpResultProxy(promise, AccountModelProxy);
        };
        // PUT /accounts/{accountId}/mailInscribe 修改 Account 的邮件落款信息
        _this.updateAccountMailInscribe = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/mailInscribe",
                data: data.data,
            });
            return proxy.httpResultProxy(promise, AccountEmailInscribeProxy);
        };
        // GET /accounts/{accountId}/mailInscribe 获取 Account 的邮件落款信息
        _this.getQuillEditorContent = function (data) {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/mailInscribe",
            });
            return proxy.httpResultProxy(promise, AccountEmailInscribeProxy);
        };
        _this.getPublicAccounts = function () {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT + "?open=true",
            });
            return proxy.httpResultProxy(promise, AccountPageProxy);
        };
        _this.setUserToAccountAdmin = function (data) {
            var promise = _super.prototype.post.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/admin",
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.getAccountProfile = function (accountId) {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT + ("/" + accountId + "/profile"),
            });
            return proxy.httpResultProxy(promise, AccountProfileProxy);
        };
        _this.newAccountProfile = function (data) {
            var promise = _super.prototype.post.call(_this, {
                url: GET_ACCOUNT + ("/" + data.accountId + "/profile"),
                data: data.data,
            });
            return proxy.httpResultProxy(promise, AccountProfileProxy);
        };
        _this.updateAccountProfile = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + ("/" + data.accountId + "/profile"),
                data: data.data,
            });
            return proxy.httpResultProxy(promise, AccountProfileProxy);
        };
        // 扩展属性
        _this.getExtendCategories = function (data) {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories",
            });
            return proxy.httpResultProxy(promise);
        };
        _this.getExtendAttrResource = function (data) {
            var promise = _super.prototype.get.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/resources",
            });
            return proxy.httpResultProxy(promise);
        };
        _this.addExtendCategories = function (data) {
            var promise = _super.prototype.post.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories",
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.updateExtendCategory = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories/" + data.categoryId,
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.deleteExtendCategory = function (data) {
            var promise = _super.prototype.delete.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories/" + data.categoryId,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.addExtendAttribute = function (data) {
            var promise = _super.prototype.post.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories/" + data.categoryId + "/entries",
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.updateExtendAttribute = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories/" + data.categoryId + "/entries/" + data.entryId,
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.deleteExtendAttribute = function (data) {
            var promise = _super.prototype.delete.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories/" + data.categoryId + "/entries/" + data.entryId,
            });
            return proxy.httpResultProxy(promise);
        };
        _this.ascendExtendedAttribute = function (data) {
            var promise = _super.prototype.put.call(_this, {
                url: GET_ACCOUNT + "/" + data.accountId + "/extattrs/categories/" + data.categoryId + "/entryorders",
                data: data.data,
            });
            return proxy.httpResultProxy(promise);
        };
        return _this;
    }
    return AccountService;
}(ServiceBase));
export { AccountService };
//# sourceMappingURL=accounts.js.map